@@ -1,13 +1,26 @@
 /*
     This file is part of kcontacts.
-    SPDX-FileCopyrightText: 2016 Benjamin Löwe <benni@mytum.de>
+    Copyright (c) 2016 Benjamin Löwe <benni@mytum.de>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "datetimetest.h"
 #include <QTest>
-#include <vcardtool_p.h>
+#include <vcardtool.h>
 
 DateTimeTest::DateTimeTest(QObject *parent)
     : QObject(parent)
@@ -22,8 +35,7 @@ void DateTimeTest::shouldParseDateTime()
 {
     using namespace KContacts;
 
-    QDateTime expected;
-    QDateTime dt;
+    QDateTime expected, dt;
     bool timeIsValid;
 
     dt = VCardTool::parseDateTime(QStringLiteral("2016-01-20T12:33:30+0200"));
@@ -68,12 +80,12 @@ void DateTimeTest::shouldParseDateTime()
     QCOMPARE(dt.time(), QTime(12, 33));
 
     dt = VCardTool::parseDateTime(QStringLiteral("--0120"));
-    expected = QDateTime(QDate(-1, 1, 20).startOfDay());
+    expected = QDateTime(QDate(-1, 1, 20));
     QCOMPARE(dt, expected);
     QVERIFY(dt.isValid());
 
     dt = VCardTool::parseDateTime(QStringLiteral("--01-20"));
-    expected = QDateTime(QDate(-1, 1, 20).startOfDay());
+    expected = QDateTime(QDate(-1, 1, 20));
     QCOMPARE(dt, expected);
     QVERIFY(dt.isValid());
 }
@@ -83,8 +95,7 @@ void DateTimeTest::shouldCreateDateTime()
     using namespace KContacts;
 
     QDateTime dt;
-    QString str;
-    QString expected;
+    QString str, expected;
 
     dt = QDateTime(QDate(2016, 1, 20), QTime(12, 33, 30), Qt::UTC);
     str = VCardTool::createDateTime(dt, VCard::v4_0);
@@ -137,8 +148,7 @@ void DateTimeTest::shouldCreateDate()
     using namespace KContacts;
 
     QDate d;
-    QString str;
-    QString expected;
+    QString str, expected;
 
     d = QDate(2016, 1, 20);
     str = VCardTool::createDate(d, VCard::v3_0);
@@ -162,5 +172,3 @@ void DateTimeTest::shouldCreateDate()
 }
 
 QTEST_MAIN(DateTimeTest)
-
-#include "moc_datetimetest.cpp"
